
deephaven_ipywidgets
=====================================

Version: |release|

A Custom Jupyter Widget Library


Quickstart
----------

To get started with deephaven_ipywidgets, install with pip::

    pip install deephaven_ipywidgets

or with conda::

    conda install deephaven_ipywidgets


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/
